package com.gic.spark.tag;

import com.gic.spark.filter.*;
import com.gic.spark.util.DingtalkMessageUtil;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/5/13
 */
public class TagFilterFactory {

    private static TagFilterFactory instance;

    public static TagFilterFactory getInstance() {
        if(null==instance){
            instance=new TagFilterFactory();
        }
        return instance;
    }
    private TagFilterFactory(){}

    public TagFilter getTagFilter(String tagEsFieldName){
        TagFilter tagFilter=null;
        switch (tagEsFieldName) {
            //积分信息
            case TagConstant.TAG_CODE_ACCUMULATED_INTEGRAL:
                tagFilter= TagAccumulatedIntegralFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_ABOUT_EXPIRE_INTEGRAL:
                tagFilter= TagAboutExpireIntegralFilter.getInstance();
                break;


            //卡卷类
            case TagConstant.TAG_CODE_CURRENT_COUPON_NUM:
                tagFilter= TagCurrentCouponNumFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_UNCLAIMED_COUPON:
                tagFilter= TagCouponFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_GET_NO_CANCEL_COUPON:
                tagFilter= TagCouponFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_NO_CANCEL_EXPIRES_COUPON:
                tagFilter= TagCouponFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_CANCEL_COUPON:
                tagFilter=TagCouponFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_DONATION_IN_COUPON:
                tagFilter=TagCouponFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_YET_DONATION_COUPON:
                tagFilter=TagCouponFilter.getInstance();
                break;


            //消费统计
            case TagConstant.TAG_CODE_CONSUMPTION_TIME:
                tagFilter=TagConsumptionTimeFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_PER_CUSTOMER_TRANSACTION:
                tagFilter=TagPerCustomerTransactionFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_ASSOCIATED_PURCHASE_RATE:
                tagFilter=TagAssociatedPurchaseRateFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_AVERAGE_DISCOUNT_FACTOR:
                tagFilter=TagAverageDiscountFactorFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_CONSUMPTION_SLEEP_DAYS:
                tagFilter=TagConsumptionSleepDaysFilter.getInstance();
                break;


            //消费金额记录
            case TagConstant.TAG_CODE_CONSUME_TOTAL:
                tagFilter=TagConsumeTotalFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_HISTORY_CONSUME_TOTAL:
                tagFilter=TagHistoryConsumeTotalFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_FIRST_CONSUMPTION_MONEY:
                tagFilter=TagFirstConsumptionMoneyFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_LATELY_CONSUMPTION_MONEY:
                tagFilter=TagLatelyConsumptionMoneyFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_TOP_SINGLE_CONSUMPTION_MONEY:
                tagFilter=TagTopSingleConsumptionMoneyFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_LOWEST_SINGLE_CONSUMPTION_MONEY:
                tagFilter=TagLowestSingleConsumptionMoneyFilter.getInstance();
                break;


            //消费时间
            case TagConstant.TAG_CODE_FIRST_CONSUME_TIME:
                tagFilter=TagFirstConsumeTimeFilter.getInstance();
                break;
//            case TagConstant.TAG_CODE_HISTORY_CONSUME_TIME:
//                tagFilter=
//                break;
            case TagConstant.TAG_CODE_LATELY_CONSUME_TIME:
                tagFilter=TagLatelyConsumeTimeFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_CONSUME_TIME:
                tagFilter=TagConsumeTimeFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_CONSUME_SLEEP_DAY:
//                tagFilter=
                break;

            //渠道
            case TagConstant.TAG_CODE_FIRST_CONSUMPTION_CHANNEL:
                tagFilter=TagFirstConsumptionChannelFilter.getInstance();
                break;
            case  TagConstant.TAG_CODE_LATELY_CONSUMPTION_CHANNEL:
                tagFilter=TagLatelyConsumptionChannelFilter.getInstance();
                break;

            //线下消费门店
            case TagConstant.TAG_CODE_FIRST_OFFLINE_CONSUMPTION_STORE:
                tagFilter=TagFirstOfflineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_RECENTLY_OFFLINE_CONSUMPTION_STORE:
                tagFilter=TagRecentlyOfflineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_HISTORY_OFFLINE_CONSUMPTION_STORE:
                tagFilter=TagHistoryOfflineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_OFFLINE_CONSUMPTION_STORE:
                tagFilter=TagOfflineConsumptionStoreFilter.getInstance();
                break;

            //线上消费店铺
            case TagConstant.TAG_CODE_FIRST_ONLINE_CONSUMPTION_STORE:
                tagFilter=TagFirstOnlineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_LATELY_ONLINE_CONSUMPTION_STORE:
                tagFilter=TagLatelyOnlineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_HISTORY_ONLINE_CONSUMPTION_STORE:
                tagFilter=TagHistoryOnlineConsumptionStoreFilter.getInstance();
                break;
            case TagConstant.TAG_CODE_ONLINE_CONSUMPTION_STORE:
                tagFilter=TagOnlineConsumptionStoreFilter.getInstance();
                break;

            default:
                DingtalkMessageUtil.sendAlertMessage("暂未支持的非实时标签: " + tagEsFieldName);
                break;
        }
        return tagFilter;
    }
}
